@@ -33,11 +33,13 @@ def main():
     container_name = str("containertest1")
 
     # Create the container
-    container_client = blob_service_client.create_container(container_name)
+    # container_client = blob_service_client.create_container(container_name)
+
+    # container_client = blob_service_client.get_container_client(container_name)
 
     blob_service_client: BlobServiceClient
     blob_client = blob_service_client.get_blob_client(
-        container=container_name, blob="test1"
+        container=container_name, blob="test4"
     )
 
-    blob_client.upload_blob(json.dumps(dict(test1="test2")))
+    blob_client.upload_blob(json.dumps(dict(test1="test3")))
